

import React, { useMemo, useState } from 'react';
import { Dimensions, View, ViewStyle } from 'react-native';
import { ScrollView } from 'react-native-gesture-handler';

interface PageProps {
    /**
     *  page的外部样式
     */
    style?:ViewStyle

    /**
     *  是否横着滑动,默认是的
     */
    horizontal?:boolean
    
    /**
    *  子组件
    */
    children?: Element[] | Element

    /**
     *  是否可以滚动
     */
    scrollEnabled?:boolean

    /**
     *  当滚动停止
     */
    onPageSelected?:(page:number)=>void
}

/**
 * 字体图标
 * @param props 
 */
export default function Icon(props: PageProps) {

    const {style,horizontal=true,onPageSelected,scrollEnabled=true} = props
    const [pageSize,setPageSize] = useState<{width:number,height:number}>(Dimensions.get('window'))

    const onLayout = (event: { nativeEvent: { layout: { width: number, height: number } } }) => {
        let size = event.nativeEvent.layout
        setPageSize(size)
    }

    let children = useMemo(()=>{
        let children = React.Children.map(props.children, (child: any, index) => {
            let tempProps = { ...child.props }
            tempProps.style = {...tempProps.style,width:pageSize.width,height:pageSize.height}
            return React.cloneElement(child, tempProps);
        })
        return children
    },[pageSize,props.children])

    const onMomentumScrollEnd = (e:any)=>{
        //求出偏移量
        const offsetX = e.nativeEvent.contentOffset.x;
        const offsetY = e.nativeEvent.contentOffset.y;

        //求出当前页数
        const pageIndex = horizontal ?  Math.round(offsetX / pageSize.width) : Math.round(offsetY / pageSize.height);
        onPageSelected && onPageSelected(pageIndex)
    }

    return (
        <View style={{flex:1,...style}}
            onLayout={onLayout}>
            <ScrollView 
                horizontal={horizontal} 
                pagingEnabled={true}
                scrollEnabled={scrollEnabled}
                showsHorizontalScrollIndicator={false}
                showsVerticalScrollIndicator={false}
                keyboardDismissMode='on-drag'
                keyboardShouldPersistTaps='handled'
                onMomentumScrollEnd={onMomentumScrollEnd}
                >
                {children}
            </ScrollView>
        </View>
    )
}

